summaryrefslogtreecommitdiffstats
path: root/digikam/digikam/albumdb.h
diff options
context:
space:
mode:
Diffstat (limited to 'digikam/digikam/albumdb.h')
-rw-r--r--digikam/digikam/albumdb.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/digikam/digikam/albumdb.h b/digikam/digikam/albumdb.h
index ccbd735..438f9f7 100644
--- a/digikam/digikam/albumdb.h
+++ b/digikam/digikam/albumdb.h
@@ -163,7 +163,7 @@ public:
/**
* Adds a new tag to the database with given name, icon and tqparent id.
* @param tqparentTagID the id of the tag which will become the new tags tqparent
* @param name the name of the tag
* @param iconKDE the name of the icon file (this is filename which kde
* iconloader can load up)
@@ -171,7 +171,7 @@ public:
* Note: if the iconKDE parameter is empty, then the iconID parameter is used
* @return the id of the tag added or -1 if it failed
*/
- int addTag(int tqparentTagID, const TQString& name,
+ int addTag(int parentTagID, const TQString& name,
const TQString& iconKDE, TQ_LLONG iconID);
/**
@@ -203,7 +203,7 @@ public:
* Set the tqparent tagid for the tag. This is equivalent to reparenting
* the tag
* @param tagID the id of the tag
- * @param newParentTagID the new tqparentid for the tag
+ * @param newParentTagID the new parentid for the tag
*/
void setTagParentID(int tagID, int newParentTagID);
@@ -163,7 +163,7 @@ public:
/**
* Adds a new tag to the database with given name, icon and tqparent id.
- * @param tqparentTagID the id of the tag which will become the new tags tqparent
+ * @param parentTagID the id of the tag which will become the new tags tqparent
* @param name the name of the tag
* @param iconKDE the name of the icon file (this is filename which kde